@@ -92,7 +92,9 @@ extern int checkforbadword(struct channel *, char *, char *, char *);
 extern int checkforbadnick(struct channel *, char *, char *);
 extern int checkforautorejoin(struct channel *, char *, char *);
 extern int checkforpartrejoin(struct channel *, char *, char *);
+extern int checkforaction(struct channel *, char *, char *, int);
 extern int delchankey(struct channel *);
+extern int delchanlimit(struct channel *);
 extern int delpermban(struct channel *, char *);
 extern int delnickbk(struct channel *, char *);
 extern int delwordbk(struct channel *, char *);
@@ -120,7 +122,9 @@ extern int isfriend(struct channel *, char *, char *);
 extern int deltaflags(struct channel *, char *, char);
 extern int isvalidchannel(char *);
 extern int hasuserflags(struct channel *, char *, char *, char *);
+extern int noexpiredlogons(struct channel *);
 extern unsigned int getrandom(unsigned int);
+extern long getfilesize(char *);
 extern struct authed *addnewauthed(struct channel *, time_t, struct botuser *, char *);
 extern struct botuser *addbotuser(char *, char *);
 extern struct botuser *addnewadmin(char *, char *);
@@ -216,6 +220,7 @@ extern void showlast(struct channel *, char *, int, char *);
 extern void showseen(struct channel *, char *, int, char *);
 extern void setchanmode(struct channel *);
 extern void setchankey(struct channel *, char *);
+extern void setchanlimit(struct channel *, char *);
 extern void channelsync(struct channel *);
 extern void cleartobek(struct channel *);
 extern void getnthmode(char *, int, char *);
