@@ -62,6 +62,7 @@ int main(int argc, char *argv[])
 	int do_help;
 	int do_version;
 	fd_set rsock;
+	FILE *pidfile;
 	pid_t newpid;
 	struct timeval tv;
 #ifdef NEW_SIGNALS
@@ -108,6 +109,19 @@ int main(int argc, char *argv[])
 	if(do_version) {
 		exit(EXIT_SUCCESS);
 	}
+	/* check if there is already a oer running started from this
+	   directory */
+	if((pidfile = fopen("oer.pid", "r")) != NULL) {
+		if(fgets(stringbuffer, WRITE_BUFFER_LENGTH, pidfile)) {
+			/* exists, check if process is running */
+			if(!kill(atoi(stringbuffer), SIGHUP)) {
+				oer_debug(OER_DEBUG_FATAL, "main->oer seems to be running, if this is not the case remove oer.pid from the current directory\n");
+				fclose(pidfile);
+				exit(EXIT_FAILURE);
+			}
+		}
+		fclose(pidfile);
+	}
 #ifdef HAVE_LOCALE_H
 	if((locptr = setlocale(LC_CTYPE, "")) == NULL) {
 		oer_debug(OER_DEBUG_FATAL, "main->setlocale() failed for %s\n");
@@ -132,6 +146,18 @@ int main(int argc, char *argv[])
 		close(STDERR_FILENO);
 		do_console = 0;
 	}
+	/* create new pidfile */
+	if((pidfile = fopen("oer.pid", "w")) == NULL) {
+		oer_debug(OER_DEBUG_FATAL, "main->couldn't open oer.pid: %s\n", strerror(errno));
+		exit(EXIT_FAILURE);
+	}	
+	snprintf(stringbuffer, WRITE_BUFFER_LENGTH, "%d", getpid());
+	if(fputs(stringbuffer, pidfile) == EOF) {
+		oer_debug(OER_DEBUG_FATAL, "main->couldn't write to oer.pid: %s\n", strerror(errno));
+		fclose(pidfile);
+		exit(EXIT_FAILURE);
+	}
+	fclose(pidfile);
 #ifdef NEW_SIGNALS
 	sigemptyset(&act.sa_mask);
         act.sa_flags = SA_RESTART;
