@@ -1007,6 +1007,7 @@ void parsemsg(char *nick, char *userhost, char *target, char *message)
 	int ppos;
 	int is_command;
 	struct channel *this;
+	char np[NICKLEN + 1];
 #ifdef DEBUG
         oer_debug(OER_DEBUG_INFO, "parsemsg(\"%s\", \"%s\", \"%s\", \"%s\")\n", nick, userhost, target, message);
 #endif
@@ -1089,26 +1090,19 @@ void parsemsg(char *nick, char *userhost, char *target, char *message)
 		return;
 	}
 	/* check for command */
-	is_command = 0;
 	ppos = 0;
-	if(!strncasecmp(message, mystate->nick, strlen(mystate->nick))) {
-		is_command = 1;
-                ppos = strlen(mystate->nick);
-                if(isspace((int)message[ppos])) {
-                        while(isspace((int)message[ppos])) {
-                                ppos++;
-                        }
-                }
-        }
-	if(!strncasecmp(message, mystate->prefix, strlen(mystate->prefix))) {
-		is_command = 1;
-                ppos = strlen(mystate->prefix);
-                if(isspace((int)message[ppos])) {
-                        while(isspace((int)message[ppos])) {
-                                ppos++;
-                        }
-                }
-        }
+	is_command = 0;
+	if((ppos = parse(message, ppos, " ", np, NICKLEN, 0)) >= 0) {
+		/* it is possible that parse() will fail if message
+		   has just one word and it is longer than NICKLEN */
+		if(!strcasecmp(np, mystate->nick)) {
+			is_command = 1;
+		}
+		if(!strncasecmp(np, mystate->prefix, strlen(mystate->prefix))) {
+			is_command = 1;
+			ppos = strlen(mystate->prefix);
+		}
+	}
 	if(is_command) {
 		/* here is when we parse all commands */
 		parsecommand(target, nick, userhost, message + ppos);
